# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.46.03-BETA
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ScreenshotOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end': 'str',
        'height': 'int',
        'screenshot': 'str',
        'start': 'str',
        'status_message': 'str',
        'width': 'int'
    }

    attribute_map = {
        'end': 'end',
        'height': 'height',
        'screenshot': 'screenshot',
        'start': 'start',
        'status_message': 'statusMessage',
        'width': 'width'
    }

    def __init__(self, end=None, height=None, screenshot=None, start=None, status_message=None, width=None):
        """
        ScreenshotOutputV1 - a model defined in Swagger
        """

        self._end = None
        self._height = None
        self._screenshot = None
        self._start = None
        self._status_message = None
        self._width = None

        if end is not None:
          self.end = end
        if height is not None:
          self.height = height
        if screenshot is not None:
          self.screenshot = screenshot
        if start is not None:
          self.start = start
        if status_message is not None:
          self.status_message = status_message
        if width is not None:
          self.width = width

    @property
    def end(self):
        """
        Gets the end of this ScreenshotOutputV1.
        The end of the display range window used in the screenshot as an ISO-8601 timestamp

        :return: The end of this ScreenshotOutputV1.
        :rtype: str
        """
        return self._end

    @end.setter
    def end(self, end):
        """
        Sets the end of this ScreenshotOutputV1.
        The end of the display range window used in the screenshot as an ISO-8601 timestamp

        :param end: The end of this ScreenshotOutputV1.
        :type: str
        """

        self._end = end

    @property
    def height(self):
        """
        Gets the height of this ScreenshotOutputV1.
        The screenshot height if a screenshot URL is being returned and a contentSelector was specified in the request

        :return: The height of this ScreenshotOutputV1.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this ScreenshotOutputV1.
        The screenshot height if a screenshot URL is being returned and a contentSelector was specified in the request

        :param height: The height of this ScreenshotOutputV1.
        :type: int
        """

        self._height = height

    @property
    def screenshot(self):
        """
        Gets the screenshot of this ScreenshotOutputV1.
        The Base64 encoded screenshot data, or the URL of the generated and cached screenshot if the screenshot request did not specify a period

        :return: The screenshot of this ScreenshotOutputV1.
        :rtype: str
        """
        return self._screenshot

    @screenshot.setter
    def screenshot(self, screenshot):
        """
        Sets the screenshot of this ScreenshotOutputV1.
        The Base64 encoded screenshot data, or the URL of the generated and cached screenshot if the screenshot request did not specify a period

        :param screenshot: The screenshot of this ScreenshotOutputV1.
        :type: str
        """

        self._screenshot = screenshot

    @property
    def start(self):
        """
        Gets the start of this ScreenshotOutputV1.
        The start of the display range window used in the screenshot as an ISO-8601 timestamp

        :return: The start of this ScreenshotOutputV1.
        :rtype: str
        """
        return self._start

    @start.setter
    def start(self, start):
        """
        Sets the start of this ScreenshotOutputV1.
        The start of the display range window used in the screenshot as an ISO-8601 timestamp

        :param start: The start of this ScreenshotOutputV1.
        :type: str
        """

        self._start = start

    @property
    def status_message(self):
        """
        Gets the status_message of this ScreenshotOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :return: The status_message of this ScreenshotOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ScreenshotOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :param status_message: The status_message of this ScreenshotOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def width(self):
        """
        Gets the width of this ScreenshotOutputV1.
        The screenshot width if a screenshot URL is being returned and a contentSelector was specified in the request

        :return: The width of this ScreenshotOutputV1.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this ScreenshotOutputV1.
        The screenshot width if a screenshot URL is being returned and a contentSelector was specified in the request

        :param width: The width of this ScreenshotOutputV1.
        :type: int
        """

        self._width = width

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ScreenshotOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from seeq.sdk import *

from ._item import Item
from ._user import ItemWithOwnerAndAcl

from .. import _common
from .. import _login


class Folder(ItemWithOwnerAndAcl):
    def _pull(self, item_id):
        folders_api = FoldersApi(_login.client)
        folder_output = folders_api.get_folder(folder_id=item_id)  # type: FolderOutputV1
        self._pull_owner_and_acl(folder_output.owner.id)
        self._pull_ancestors(folder_output.ancestors)
        self.provenance = Item.PULL

    def _find_by_name(self, folder_id):
        folders_api = FoldersApi(_login.client)

        if folder_id and folder_id != _common.PATH_ROOT:
            folders = folders_api.get_folders(filter='owner',
                                              folder_id=folder_id,
                                              limit=10000)  # type: FolderOutputListV1
        else:
            folders = folders_api.get_folders(filter='owner',
                                              limit=10000)  # type: FolderOutputListV1

        content_dict = {content.name.lower(): content for content in folders.content}
        if self.name.lower() in content_dict and content_dict[self.name.lower()].type == 'Folder':
            return content_dict[self.name.lower()]

        return None

    def push(self, parent_folder_id, datasource_maps, item_map, *, owner=None, label=None,
             access_control=None):
        items_api = ItemsApi(_login.client)
        folders_api = FoldersApi(_login.client)
        folder_item = self.find_me(label)

        if folder_item is None and self.provenance == Item.CONSTRUCTOR:
            folder_item = self._find_by_name(parent_folder_id)

        if not folder_item:
            folder_input = FolderInputV1()
            folder_input.name = self['Name']
            if 'Description' in self:
                folder_input.description = self['Description']
            folder_input.owner_id = self.decide_owner(datasource_maps, item_map, owner=owner)
            folder_input.parent_folder_id = parent_folder_id if parent_folder_id != _common.PATH_ROOT else None

            folder_output = folders_api.create_folder(body=folder_input)

            items_api.set_properties(id=folder_output.id, body=[
                ScalarPropertyV1(name='Datasource Class', value=_common.DEFAULT_DATASOURCE_CLASS),
                ScalarPropertyV1(name='Datasource ID', value=_common.DEFAULT_DATASOURCE_ID),
                ScalarPropertyV1(name='Data ID', value=self._construct_data_id(label))])
        else:
            folder_output = folders_api.get_folder(folder_id=folder_item.id)  # type: FolderOutputV1

            props = [ScalarPropertyV1(name='Name', value=self['Name'])]
            if 'Description' in self:
                props.append(ScalarPropertyV1(name='Description', value=self['Description']))

            # If the folder happens to be archived, un-archive it. If you're pushing a new copy it seems likely
            # you're intending to revive it.
            props.append(ScalarPropertyV1(name='Archived', value=False))

            items_api.set_properties(id=folder_output.id, body=props)

            owner_id = self.decide_owner(
                datasource_maps, item_map, owner=owner, current_owner_id=folder_output.owner.id)

            self._push_owner_and_location(folder_output, owner_id, parent_folder_id)

        item_map[self.id.upper()] = folder_output.id.upper()

        if access_control:
            self._push_acl(folder_output.id, datasource_maps, item_map, access_control)

        return folder_output
